"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const tslib_1 = require("tslib");
const core_1 = require("@oclif/core");
const fs_1 = tslib_1.__importDefault(require("fs"));
const i18next_1 = require("i18next");
const path = tslib_1.__importStar(require("path"));
const prompts_1 = require("@clack/prompts");
const picocolors_1 = tslib_1.__importDefault(require("picocolors"));
const integration_1 = require("../../domains/integration");
const project_name_1 = require("../../domains/project-name");
const git_repository_1 = require("../../domains/git-repository");
const directory_1 = require("../../domains/directory");
const functions_1 = require("../../domains/magento2/functions");
const terminalHelpers_1 = require("../../domains/magento2/functions/terminalHelpers");
const installMagento_1 = require("../../domains/magento2/installMagento");
const docker_1 = require("../../domains/magento2/docker");
const installDeps_1 = tslib_1.__importDefault(require("../../domains/magento2/functions/installDeps"));
class GenerateStore extends core_1.Command {
    async run() {
        let magentoDomain = '';
        const sp = (0, prompts_1.spinner)();
        (0, prompts_1.intro)((0, i18next_1.t)('command.generate_store.message.intro'));
        const projectName = await (0, project_name_1.getProjectName)((0, i18next_1.t)('command.generate_store.input.project_name'));
        const projectDir = path.resolve(projectName);
        if (await (0, directory_1.existsDirectory)(projectDir)) {
            const overwrite = await (0, prompts_1.confirm)({
                message: (0, i18next_1.t)('command.generate_store.input.overwrite', {
                    projectName
                })
            });
            if ((0, prompts_1.isCancel)(overwrite)) {
                (0, terminalHelpers_1.logSimpleWarningMessage)((0, i18next_1.t)('command.generate_store.message.canceled'));
                this.exit(0);
            }
            if (overwrite) {
                sp.start(picocolors_1.default.cyan((0, i18next_1.t)('command.generate_store.progress.delete_start')));
                await fs_1.default.rmSync(projectDir, { recursive: true, force: true });
                await fs_1.default.mkdirSync(projectDir);
                sp.stop(picocolors_1.default.green((0, i18next_1.t)('command.generate_store.progress.delete_end')));
            }
            if (!overwrite) {
                (0, terminalHelpers_1.logSimpleErrorMessage)((0, i18next_1.t)('command.generate_store.message.skipping'));
                this.exit(0);
            }
        }
        const integration = await (0, integration_1.getIntegration)({
            message: (0, i18next_1.t)('command.generate_store.input.integration'),
            customIntegrationRepositoryMessage: (0, i18next_1.t)('command.generate_store.input.custom_integration_repository')
        });
        const { name: integrationName } = integration;
        if (integrationName === 'Magento 2') {
            await (0, docker_1.checkDocker)();
            const isInstallMagento = await (0, functions_1.installMg2Prompt)((0, i18next_1.t)('command.generate_store.magento.install'));
            if ((0, prompts_1.isCancel)(isInstallMagento)) {
                (0, terminalHelpers_1.logSimpleWarningMessage)((0, i18next_1.t)('command.generate_store.message.canceled'));
                process.exit(0);
            }
            const { magentoDirName, magentoDomainName, magentoAccessKey, magentoSecretKey } = await (0, functions_1.getMagentoDetails)();
            magentoDomain = magentoDomainName;
            if (isInstallMagento) {
                await (0, installMagento_1.installMagento)({
                    isInstallMagento,
                    magentoDirName,
                    magentoDomainName,
                    magentoAccessKey,
                    magentoSecretKey
                });
            }
        }
        sp.start((0, i18next_1.t)('command.generate_store.progress.vsf_start'));
        await (0, git_repository_1.cloneGitRepository)({
            projectDir,
            gitRepositoryURL: integration.gitRepositoryURL
        });
        await (0, functions_1.copyEnv)(projectDir, magentoDomain);
        await (0, git_repository_1.terminateGitRepository)(projectDir);
        sp.stop(picocolors_1.default.green((0, i18next_1.t)('command.generate_store.progress.vsf_end')));
        await (0, installDeps_1.default)(projectDir);
        if (integration.documentationURL) {
            (0, prompts_1.note)((0, i18next_1.t)('command.generate_store.message.configure', {
                documentationURL: integration.documentationURL
            }));
        }
        (0, terminalHelpers_1.simpleLog)((0, i18next_1.t)('command.generate_store.message.start'));
        (0, terminalHelpers_1.simpleLog)((0, i18next_1.t)('command.generate_store.message.start_command', {
            projectName
        }), picocolors_1.default.magenta);
        (0, terminalHelpers_1.simpleLog)('');
        (0, terminalHelpers_1.simpleLog)('Happy coding! 🎉', picocolors_1.default.green);
        this.exit(0);
    }
}
exports.default = GenerateStore;
GenerateStore.description = (0, i18next_1.t)('command.generate_store.description');
GenerateStore.examples = ['<%= config.bin %> <%= command.id %>'];
GenerateStore.flags = {};
GenerateStore.args = [];
//# sourceMappingURL=store.js.map