"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const child_process_1 = require("child_process");
const terminalHelpers_1 = require("../functions/terminalHelpers");
/** Checking if Docker is installed and running on user's machine */
const checkDocker = async () => {
    (0, terminalHelpers_1.logSimpleInfoMessage)('🔍 Checking if Docker is installed...');
    const docker = (0, child_process_1.spawn)('docker', ['info']);
    docker.stderr.on('data', (data) => {
        (0, terminalHelpers_1.simpleLog)(data.toString());
    });
    const isDockerInstalled = await new Promise((resolve) => {
        docker.on('close', (code) => resolve(code === 0));
    });
    if (!isDockerInstalled) {
        (0, terminalHelpers_1.logSimpleErrorMessage)('Docker is not installed or not running. Please make sure that prerequisites are complied with and run command again. For more information, please visit https://docs.vuestorefront.io/magento/installation-setup/configure-magento.html');
        process.exit(1);
    }
};
exports.default = checkDocker;
//# sourceMappingURL=checkDocker.js.map